@@ -98,25 +98,38 @@ class PackageTemplate(Package):
                 catkin_deps.remove(dep)
                 continue
             if dep.lower() == 'genmsg':
+                sys.stderr.write('WARNING: Packages with messages or services should not depend on genmsg, but on message_generation and message_runtime\n')
                 buildtool_depends.append(Dependency('genmsg'))
                 continue
+            if dep.lower() == 'message_generation':
+                if not 'message_runtime' in catkin_deps:
+                    sys.stderr.write('WARNING: Packages with messages or services should depend on both message_generation and message_runtime\n')
+                build_depends.append(Dependency('message_generation'))
+                continue
+            if dep.lower() == 'message_runtime':
+                if not 'message_generation' in catkin_deps:
+                    sys.stderr.write('WARNING: Packages with messages or services should depend on both message_generation and message_runtime\n')
+                run_depends.append(Dependency('message_runtime'))
+                continue
             pkg_catkin_deps.append(Dependency(dep))
+        for dep in pkg_catkin_deps:
+            build_depends.append(Dependency(dep))
+            run_depends.append(Dependency(dep))
+        if boost_comps:
+            if not system_deps:
+                system_deps = ['boost']
+            elif not 'boost' in system_deps:
+                system_deps.append('boost')
         for dep in system_deps or []:
             if not dep.lower().startswith('python-'):
                 build_depends.append(Dependency(dep))
             run_depends.append(Dependency(dep))
-        for dep in catkin_deps:
-            build_depends.append(Dependency(dep))
-            run_depends.append(Dependency(dep))
-        if boost_comps and not 'boost' in system_deps:
-            build_depends.append(Dependency('boost'))
-            run_depends.append(Dependency('boost'))
         package_temp = PackageTemplate(
             name=package_name,
             version=version or '0.0.0',
             description=description or 'The %s package' % package_name,
             buildtool_depends=buildtool_depends,
-            build_depends=pkg_catkin_deps,
+            build_depends=build_depends,
             run_depends=run_depends,
             catkin_deps=catkin_deps,
             system_deps=system_deps,
@@ -229,6 +242,8 @@ def create_cmakelists(package_template, rosdistro):
                ' '.join(package_template.boost_comps)))
     system_find_package = ''
     for sysdep in package_template.system_deps:
+        if sysdep == 'boost':
+            continue
         if sysdep.startswith('python-'):
             system_find_package += '# '
         system_find_package += 'find_package(%s REQUIRED)\n' % sysdep
